tty-web โ web-based terminal emulator library.
Opens a real PTY in the browser over WebSocket. Can be used as a standalone binary or embedded as a library into other applications.
tty-web โ web-based terminal emulator library.
Opens a real PTY in the browser over WebSocket. Can be used as a standalone binary or embedded as a library into other applications.